# -*- coding: utf-8 -*-
#
# Copyright European Organization for Nuclear Research (CERN)
# All rights reserved
#
# Please look at the supplied documentation for the user's
# license
#
# Author: Vasilis.Vlachoudis@cern.ch
# Date:   23-Nov-2018

import os
import re

from log import error
from deck import Config

#===============================================================================
# A container class to keep the programs
# It should contain only static and class methods
#===============================================================================
class StabConfig(Config):
	SECTION   = "Stab"	# Configuration section name

	DEFAULT_EXE = "stab"

	CYCLE     = "stab_"	# prefix of temporary cycle directory

	directory = ""		# Executable installation directory
	var       = ""		# environment variable
	program   = DEFAULT_EXE	# Main application program
	version   = "Unknown"
	released  = ""

	CYCLEDIR_PAT  = re.compile(r"^%s(\d+)$"%(CYCLE))
	CYCLEDIR2_PAT = re.compile(r"^(.*/?)%s(\d+)$"%(CYCLE))

	#-----------------------------------------------------------------------
	@staticmethod
	def checkDir():
		try:
			os.stat(StabConfig.directory)
			return False
		except OSError:
			error("Stab directory is not found or not set")
		return True

	#-----------------------------------------------------------------------
	@staticmethod
	def documentDir():
		return os.path.join(StabConfig.directory,"doc")

	#-----------------------------------------------------------------------
	# Return a command, default if cmd=empty
	#-----------------------------------------------------------------------
	@staticmethod
	def command(prg):
		if StabConfig.checkDir(): return prg
		if not prg:
			cmd = os.path.join(StabConfig.directory, prg)
			# Try fluka directory
			try:
				os.stat(cmd)
				return cmd
			except:
				pass
			return Config.command(prg)
		else:
			if prg[0] == os.path.sep:
				return prg
			else:
				return os.path.join(StabConfig.directory, prg)

	#-----------------------------------------------------------------------
	# Load from config
	#-----------------------------------------------------------------------
	@staticmethod
	def loadConfig(config):
		section = StabConfig.SECTION
		StabConfig.directory = config.getStr(section, "directory", StabConfig.directory)
		StabConfig.var       = config.getStr(section, "var",       StabConfig.var)
		StabConfig.program   = config.getStr(section, "program",   StabConfig.program)

	#-----------------------------------------------------------------------
	# Save to config
	#-----------------------------------------------------------------------
	@staticmethod
	def saveConfig(config):
		pass
